@@ -1,5 +1,7 @@
 import pytest
-from limeutils import utils
+from collections import Counter
+from icecream import ic
+from limeutils import utils, listify
 
 
 param = [(3, True), (3.0, True), (0, True), ('3.4', True), ('0.4', True), ('0.0', True),
@@ -39,3 +41,27 @@ def test_byte_conv(red, key, val):
     if val == '1.5':
         val = 1.5
     assert red.get(key) == val
+
+
+param = [
+    (['one', 'two', 'three', 'four'], 'one, two, three, or four'),
+    (['one', 'two', 'three'], 'one, two, or three'),
+    (['one', 'two'], 'one or two'),
+    (['one'], 'one'), ([], '')
+]
+@pytest.mark.parametrize('seq, out', param)
+@pytest.mark.utilfocus
+def test_oxford_comma(seq, out):
+    assert utils.oxford_comma(seq) == out
+
+
+param = [
+    ('foo', ['foo']), (['foo'], ['foo']),
+    (['foo', 'bar'], ['foo', 'bar']),
+    (('foo',), ['foo']), (('foo', 'bar'), ['foo', 'bar']),
+    ({'foo'}, ['foo']), ({'foo', 'bar'}, ['foo', 'bar'])
+]
+@pytest.mark.parametrize('data, out', param)
+@pytest.mark.focus
+def test_listify(data, out):
+    assert Counter(listify(data)) == Counter(out)
