@@ -96,4 +96,30 @@ def split_fullname(fullname: str, default: str = '',
         first, last = list_
     except ValueError:
         first, last = [*list_, default]
-    return first, last
\ No newline at end of file
+    return first, last
+
+
+def oxford_comma(sequence: Union[list, tuple, set], separator: str = 'or'):
+    sequence = sequence and list(sequence) or []
+    if not sequence:
+        return ''
+    elif len(sequence) == 1:
+        return sequence[0]
+    elif len(sequence) == 2:
+        return '{} {} {}'.format(', '.join(sequence[:-1]), separator, sequence[-1])
+    elif len(sequence) >= 3:
+        return '{}, {} {}'.format(', '.join(sequence[:-1]), separator, sequence[-1])
+    
+    
+def listify(data: Union[str, list, set, tuple]) -> list:
+    """
+    A convenience function that converts data into a list unless it's already a list.
+    :param data:    Data to check if it needs to be casted as a list
+    :return:        list
+    """
+    if isinstance(data, str):
+        return [data]
+    elif isinstance(data, (set, tuple)):
+        return list(data)
+    else:
+        return data
